#!/usr/local/bin/python3

"""

  Convert a list of png images to fits images using the same base name

"""

import os
import sys
import numpy as np
import astropy.io.fits as pyfits
import imageio
from time import gmtime, strftime  # for utc


if len(sys.argv) == 1:
  print(" ")
  print("Usage: fits_from_pngs.py file1.png file2.png ...")
  print(" ")
  print("Convert png image files to a fits files. ")
  sys.exit("Retain image name with fits extension. \n")
elif len(sys.argv) >= 2:
  infiles = sys.argv[1:]
else:
  print(" ")
  print("Usage: fits_from_pngs.py file1.png file2.png ...")
  print(" ")


# Set a overwrite flag True so that images can be overwritten
# Otherwise set it False for safety

overwriteflag = True 

# Process all the images on the command line one at a time

for infile in infiles:
                                                                              
  # Create an output file name with a fits extension from the input name

  inbase = os.path.splitext(os.path.basename(infile))[0]
  outfile = inbase + '.fits'

  # Assign image data to numpy array
  # Convert color images to grayscale using native flatten option
  
  inimage = imageio.imread(infile, as_gray=1)

  # Flip this image using numpy so that the FITS image displays
  #   with the same orientation as the PNG original
  
  outimage = np.flipud(inimage)
  

  # Create a fits image structure without checking for data validity
  
  outlist = pyfits.PrimaryHDU(outimage.astype('float32'))
  
  # Provide a new date stamp
  
  file_time = strftime("%Y-%m-%d %H:%M:%S", gmtime())
  
  # Update the new fits header
  
  outhdr = outlist.header
  outhdr['DATE'] = file_time
  outhdr['history'] = 'Generated by fits_from_pngs' 
  outhdr['history'] = 'Image file '+  infile

  # Write the fits file

  outlist.writeto(outfile, overwrite = overwriteflag)

# Exit   

exit()

  
  
  

  

  




















